/*
   _===_ _           _                  ______ _     _             _ _ _
  |  ___| |         | |                 | ___ (_)   | |           (_) | |
  | |__ | | ___  ___| |_ _ __ ___ ______| |_/ /_  __| | ___  _   _ _| | | ___ _   _ _ __
  |  __|| |/ _ \/ __| __| '__/ _ \______| ___ \ |/ _` |/ _ \| | | | | | |/ _ \ | | | '__|
  | |___| |  __/ (__| |_| | | (_) |     | |_/ / | (_| | (_) | |_| | | | |  __/ |_| | |
  \____/|_|\___|\___|\__|_|  \___/      \____/|_|\__,_|\___/ \__,_|_|_|_|\___|\__,_|_|


  Bidouilleur Arduino - Simple serveur Web utilisant l'interface Ethernet ENC28J60
  Électro-Bidouilleur, Novembre 2020
*/ 
// Inspiré de backsoon 2011-01-30 <jc@wippler.nl> License: GPLv2

#include <EtherCard.h>   // la librairie Ethernet/ENC28J60 

#define STATIC 1  // mettre à 1 pour désactiver le DHCP (les variables myip/gwip doivent alors être assignées correctement)

#if STATIC
// ethernet interface ip address
static byte myip[] = { 192,168,0,67 };
// gateway ip address
static byte gwip[] = { 192,168,0,1 };
#endif

  // ethernet mac address - must be unique on your network
static byte mymac[] = { 0x74,0x69,0x69,0x2D,0x30,0x31 }; // l'adresse MAC ethernet

  // Définition du contenu HTML à envoyer au client
  //Attention d'allouer suffisamment de mémoire dans le buffer tcp/ip pour contenir tout ce code HTML!
byte Ethernet::buffer[500]; // tcp/ip send and receive buffer

const char page[] PROGMEM =
"<html>"
  "<head>"
  "<meta http-equiv='Content-Type' content='text/html; charset=UTF-8'>"
  "<body>"
    "<h3>Électro-Bidouilleur</h3>"
    "Ce serveur web montre un exemple très simple de page web via Arduino et ENC28J60.<br />"
    "Cool, n'est-ce pas!?"
  "</body>"
"</html>"
;

void setup()
{
  Serial.begin(57600);
  Serial.println("\n[backSoon É-B]");

  // 'SS' est prédéfini comme la broche Slave Select par défaut (broche 10). La changer si une autre broche est utilisée
  if (ether.begin(sizeof Ethernet::buffer, mymac, SS) == 0) // Ouvrir la communication avec le ENC28J60
    Serial.println( "Failed to access Ethernet controller");  // Problème de comm avec le ENC28J60

#if STATIC // Compilation avec adresse ip statique
  ether.staticSetup(myip, gwip);
#else // Compilation avec adresse ip dynamique (DHCP)
  if (!ether.dhcpSetup()) // Configurer le réseau via DHCP
    Serial.println("DHCP failed"); // Problème d'assignation d'adresse IP (réseau présent?)
#endif
    // Impression des paramètres de réseau sur le port série
  ether.printIp("IP:  ", ether.myip);
  ether.printIp("GW:  ", ether.gwip);
  ether.printIp("DNS: ", ether.dnsip);
}

void loop()
{
  if (ether.packetLoop(ether.packetReceive())) // paquet TCP reçu?
  {  // Oui, envoi du contenu HTML vers le client
    memcpy_P(ether.tcpOffset(), page, sizeof page);
    ether.httpServerReply(sizeof page - 1);
  }
}
